/project/{uuid}/close — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /project/{uuid}/close

Contents

- /project/{uuid}/close
  - POST /project/{uuid}/close
    - Parameters
    - Response status codes
    - Sample session

## POST /project/{uuid}/close

Close project

### Parameters

- uuid: Project instance UUID

### Response status codes

- 404: Project instance doesn’t exist
- 204: Project closed

### Sample session

    curl -i -X POST 'http://localhost:8000/project/{uuid}/close' -d '{}'

    POST /project/{uuid}/close HTTP/1.1
    {}

    HTTP/1.1 204
    CONNECTION: keep-alive
    CONTENT-LENGTH: 0
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /project/{uuid}/close

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »